@@ -1,9 +1,4 @@
 .onAttach <- function(libname, pkgname) {
-  packageStartupMessage(
-    "Welcome to echarts4r\n\n",
-    "Docs: echarts4r.john-coene.com"
-  )
-  
   shiny::registerInputHandler("echarts4rParse", function(data, ...) {
     jsonlite::fromJSON(jsonlite::toJSON(data, auto_unbox = TRUE))
   }, force = TRUE)
